@@ -19,7 +19,6 @@ def jsonclass(
     cls: None,
     class_graph: Optional[str] = 'default',
     camelize_json_keys: Optional[bool] = None,
-    camelize_db_keys: Optional[bool] = None,
     strict_input: Optional[bool] = None,
     key_transformer: Optional[Callable[[JSONClassField], str]] = None,
     validate_all_fields: Optional[bool] = None,
@@ -34,7 +33,6 @@ def jsonclass(
     cls: type,
     class_graph: Optional[str] = 'default',
     camelize_json_keys: Optional[bool] = None,
-    camelize_db_keys: Optional[bool] = None,
     strict_input: Optional[bool] = None,
     key_transformer: Optional[Callable[[JSONClassField], str]] = None,
     validate_all_fields: Optional[bool] = None,
@@ -48,7 +46,6 @@ def jsonclass(
     cls: Optional[type] = None,
     class_graph: Optional[str] = 'default',
     camelize_json_keys: Optional[bool] = None,
-    camelize_db_keys: Optional[bool] = None,
     strict_input: Optional[bool] = None,
     key_transformer: Optional[Callable[[JSONClassField], str]] = None,
     validate_all_fields: Optional[bool] = None,
@@ -70,7 +67,6 @@ def jsonclass(
         config = Config(
             class_graph=cast(str, class_graph),
             camelize_json_keys=camelize_json_keys,
-            camelize_db_keys=camelize_db_keys,
             strict_input=strict_input,
             key_transformer=key_transformer,
             validate_all_fields=validate_all_fields,
@@ -89,7 +85,6 @@ def jsonclass(
                 cls,
                 class_graph=class_graph,
                 camelize_json_keys=camelize_json_keys,
-                camelize_db_keys=camelize_db_keys,
                 strict_input=strict_input,
                 key_transformer=key_transformer,
                 validate_all_fields=validate_all_fields,
