@@ -1,5 +1,5 @@
 """module for int validator."""
-from ..fields import FieldType
+from ..field_definition import FieldType
 from .type_validator import TypeValidator
 
 
