@@ -1,5 +1,5 @@
 """module for linkedby validator."""
-from ..field_definition import FieldDefinition, FieldStorage
+from ..field_definition import DeleteRule, FieldDefinition, FieldStorage
 from .validator import Validator
 
 
@@ -13,3 +13,5 @@ class LinkedByValidator(Validator):
         fdesc.field_storage = FieldStorage.FOREIGN_KEY
         fdesc.foreign_key = self.foreign_key
         fdesc.use_join_table = False
+        if fdesc.delete_rule is None:
+            fdesc.delete_rule = DeleteRule.NULLIFY
