@@ -1,5 +1,5 @@
 """module for linkto validator."""
-from ..field_definition import FieldDefinition, FieldStorage
+from ..field_definition import DeleteRule, FieldDefinition, FieldStorage
 from .validator import Validator
 
 
@@ -8,3 +8,5 @@ class LinkToValidator(Validator):
 
     def define(self, fdesc: FieldDefinition) -> None:
         fdesc.field_storage = FieldStorage.LOCAL_KEY
+        if fdesc.delete_rule is None:
+            fdesc.delete_rule = DeleteRule.NULLIFY
