@@ -3,8 +3,8 @@ from typing import Any
 from ..exceptions import ValidationException
 from .validator import Validator
 from ..contexts import ValidatingContext
-from ..types_resolver import resolve_types
-from ..fields import FieldDescription, FieldType
+from ..types_resolver import TypesResolver
+from ..field_definition import FieldDefinition, FieldType
 
 
 class OneOfTypeValidator(Validator):
@@ -14,14 +14,14 @@ class OneOfTypeValidator(Validator):
     def __init__(self, type_list: list[Any]) -> None:
         self.type_list = type_list
 
-    def define(self, fdesc: FieldDescription) -> None:
+    def define(self, fdesc: FieldDefinition) -> None:
         fdesc.field_type = FieldType.UNION
-        fdesc.union_types = [resolve_types(t) for t in self.type_list]
+        fdesc.union_types = [TypesResolver().resolve_types(t) for t in self.type_list]
 
     def validate(self, context: ValidatingContext) -> None:
         if context.value is None:
             return
-        for types in context.fdesc.union_types:
+        for types in context.definition.union_types:
             try:
                 types.validator.validate(context)
                 return
