@@ -1,10 +1,10 @@
 """module for writeonce validator."""
-from ..fields import FieldDescription, WriteRule
+from ..field_definition import FieldDefinition, WriteRule
 from .validator import Validator
 
 
 class WriteonceValidator(Validator):
     """Writeonce validator marks a field as writeonce."""
 
-    def define(self, fdesc: FieldDescription) -> None:
+    def define(self, fdesc: FieldDefinition) -> None:
         fdesc.write_rule = WriteRule.WRITE_ONCE
